 Reahl is a web application framework that allows a Python programmer to work in 
 terms of useful abstractions - using a single programming language.

 Reahl-doc contains documentation and examples of Reahl.

 See http://www.reahl.org/docs/current/tutorial/gettingstarted-install.d.html for
 installation instructions.
